@@ -16,12 +16,14 @@ import (
 var httpAddr = flag.String("http", "", "use SSE HTTP at this address")
 
 type SayHiParams struct {
-	Name string `json:"name" mcp:"the name to say hi to"`
+	Name string `json:"name"`
 }
 
-func SayHi(ctx context.Context, cc *mcp.ClientConnection, params *SayHiParams) ([]mcp.Content, error) {
-	return []mcp.Content{
-		mcp.TextContent{Text: "Hi " + params.Name},
+func SayHi(ctx context.Context, cc *mcp.ServerSession, params *mcp.CallToolParams[SayHiParams]) (*mcp.CallToolResult, error) {
+	return &mcp.CallToolResult{
+		Content: []*mcp.Content{
+			mcp.NewTextContent("Hi " + params.Name),
+		},
 	}, nil
 }
 
@@ -33,10 +35,10 @@ func main() {
 	}
 
 	server1 := mcp.NewServer("greeter1", "v0.0.1", nil)
-	server1.AddTools(mcp.MakeTool("greet1", "say hi", SayHi))
+	server1.AddTools(mcp.NewTool("greet1", "say hi", SayHi))
 
 	server2 := mcp.NewServer("greeter2", "v0.0.1", nil)
-	server2.AddTools(mcp.MakeTool("greet2", "say hello", SayHi))
+	server2.AddTools(mcp.NewTool("greet2", "say hello", SayHi))
 
 	log.Printf("MCP servers serving at %s\n", *httpAddr)
 	handler := mcp.NewSSEHandler(func(request *http.Request) *mcp.Server {
